#!/bin/sh
# @nix.app.product.name@ @nix.app.product.version@

###############################################################################
#           S C R I P T                         U S A G E                     #
###############################################################################
if [ ! -n "$1" ]; then
    echo "Usage: SeedLoad [BackupSetName] [OutputDirectory]"
    exit 0
fi

if [ ! -n "$2" ]; then
    echo "Usage: SeedLoad [BackupSetName] [OutputDirectory]"
    exit 0
fi

#####################  Start: User Defined Section  ###########################

# ----------------------------- SETTING_HOME -------------------------------- #
# Directory to your OBC setting home. Default to ~/.acb or ~/.obm when not    #
# set.                                                                        #
# e.g. SETTING_HOME=~/.obm                                                    #
# --------------------------------------------------------------------------- #
SETTING_HOME=

######################  END: User Defined Section  ############################

BACKUP_SET_NAME=$1
OUTPUT_DIRECTORY=$2

###############################################################################
#      R E T R I E V E            A P P _ H O M E           P A T H           #
###############################################################################

cd `dirname "$0"`
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`

###############################################################################
#      R E T R I E V E           J A V A _ H O M E           P A T H          #
###############################################################################

JAVA_HOME=/System/Library/Frameworks/JavaVM.framework/Home

if [ ! -x "$APP_HOME/jvm" ];
then
   echo "$APP_HOME/jvm does not exist! Creating a symbolic link from ${APP_HOME}/jvm to ${JAVA_HOME}"
   ln -sf "${JAVA_HOME}" "${APP_HOME}/jvm"
fi

###############################################################################
#      E X E C U T I O N          J A V A         P R O P E R T I E S         #
###############################################################################

# Set LD_LIBRARY_PATH for Lotus Notes on Linux
if [ Linux = `uname` ];
then
    NOTES_PROGRAM=`cat "$APP_HOME/bin/notesenv"`
    LD_LIBRARY_PATH=$APP_HOME/bin:$NOTES_PROGRAM:$LD_LIBRARY_PATH
    export NOTES_PROGRAM
else
    LD_LIBRARY_PATH=$APP_HOME/bin:$LD_LIBRARY_PATH
fi

SHLIB_PATH=LD_LIBRARY_PATH
export LD_LIBRARY_PATH SHLIB_PATH


# ------------------------------ BACKUP_TYPE -------------------------------- #
# Set backup type. You don't need to change this if you are backing up a      #
# file backup set.                                                            #
# Options available: FILE/DATABASE/DIFFERENTIAL/LOG                           #
# e.g. SET BACKUP_TYPE="FILE"          for file backup                        #
#  or  SET BACKUP_TYPE="DATABASE"      for Full database backup               #
#  or  SET BACKUP_TYPE="DIFFERENTIAL"  for Differential database backup       #
#  or  SET BACKUP_TYPE="LOG"           for Log database backup                #
# --------------------------------------------------------------------------- #
BACKUP_TYPE="FILE"

###############################################################################
#                  J A V A                 E X E C U T I O N                  #
###############################################################################

cd "$APP_HOME"
LIB_HOME=./bin
JAVA_OPTS="-Xmx256m -client -Djava.library.path=${LIB_HOME}"
CLASSPATH="${LIB_HOME}:${LIB_HOME}/obc.jar:${LIB_HOME}/obc-lib.jar"
MAIN_CLASS=SeedLoad

"$JAVA_HOME/bin/java" ${JAVA_OPTS} -cp "${CLASSPATH}" "${MAIN_CLASS}" "${APP_HOME}" "${BACKUP_SET_NAME}" "${OUTPUT_DIRECTORY}" "${BACKUP_TYPE}" "${SETTING_HOME}"

exit 0
